PLEASE EDIT AND DELETE THIS TEXT WHEN MAKING A PR.
THIS IS A REMINDER OF WHAT THE PR SHOULD CONTAIN.

Issue being addressed:

Did you remember to: 
* include doc strings in all commits ?
* edit the changelog.txt file describing your changes? 
